@@ -30,6 +30,7 @@
 #include <unistd.h>
 #include <sys/types.h>
 #include <dirent.h>
+#include <limits.h>
 
 #include "../parameters/parameters.h"
 #include "../lib.h"
@@ -57,7 +58,7 @@ runtime_pmdevice::runtime_pmdevice(const char *_name, const char *path) : device
 
 void runtime_pmdevice::start_measurement(void)
 {
-	char filename[4096];
+	char filename[PATH_MAX];
 	ifstream file;
 
 	before_suspended_time = 0;
@@ -65,14 +66,14 @@ void runtime_pmdevice::start_measurement(void)
         after_suspended_time = 0;
 	after_active_time = 0;
 
-	sprintf(filename, "%s/power/runtime_suspended_time", sysfs_path);
+	snprintf(filename, PATH_MAX, "%s/power/runtime_suspended_time", sysfs_path);
 	file.open(filename, ios::in);
 	if (!file)
 		return;
 	file >> before_suspended_time;
 	file.close();
 
-	sprintf(filename, "%s/power/runtime_active_time", sysfs_path);
+	snprintf(filename, PATH_MAX, "%s/power/runtime_active_time", sysfs_path);
 	file.open(filename, ios::in);
 	if (!file)
 		return;
@@ -82,17 +83,17 @@ void runtime_pmdevice::start_measurement(void)
 
 void runtime_pmdevice::end_measurement(void)
 {
-	char filename[4096];
+	char filename[PATH_MAX];
 	ifstream file;
 
-	sprintf(filename, "%s/power/runtime_suspended_time", sysfs_path);
+	snprintf(filename, PATH_MAX, "%s/power/runtime_suspended_time", sysfs_path);
 	file.open(filename, ios::in);
 	if (!file)
 		return;
 	file >> after_suspended_time;
 	file.close();
 
-	sprintf(filename, "%s/power/runtime_active_time", sysfs_path);
+	snprintf(filename, PATH_MAX, "%s/power/runtime_active_time", sysfs_path);
 	file.open(filename, ios::in);
 	if (!file)
 		return;
@@ -146,11 +147,11 @@ void runtime_pmdevice::set_human_name(char *_name)
 
 int device_has_runtime_pm(const char *sysfs_path)
 {
-	char filename[4096];
+	char filename[PATH_MAX];
 	ifstream file;
 	unsigned long value;
 
-	sprintf(filename, "%s/power/runtime_suspended_time", sysfs_path);
+	snprintf(filename, PATH_MAX, "%s/power/runtime_suspended_time", sysfs_path);
 	file.open(filename, ios::in);
 	if (!file)
 		return 0;
@@ -159,7 +160,7 @@ int device_has_runtime_pm(const char *sysfs_path)
 	if (value)
 		return 1;
 
-	sprintf(filename, "%s/power/runtime_active_time", sysfs_path);
+	snprintf(filename, PATH_MAX, "%s/power/runtime_active_time", sysfs_path);
 	file.open(filename, ios::in);
 	if (!file)
 		return 0;
@@ -177,9 +178,9 @@ static void do_bus(const char *bus)
 
 	struct dirent *entry;
 	DIR *dir;
-	char filename[4096];
+	char filename[PATH_MAX];
 
-	sprintf(filename, "/sys/bus/%s/devices/", bus);
+	snprintf(filename, PATH_MAX, "/sys/bus/%s/devices/", bus);
 	dir = opendir(filename);
 	if (!dir)
 		return;
@@ -196,23 +197,29 @@ static void do_bus(const char *bus)
 		dev = new class runtime_pmdevice(entry->d_name, filename);
 
 		if (strcmp(bus, "i2c") == 0) {
-			char devname[4096];
+			string devname;
 			char dev_name[4096];
-			sprintf(filename, "/sys/bus/%s/devices/%s/name", bus, entry->d_name);
+			bool is_adapter = false;
+
+			snprintf(filename, PATH_MAX, "/sys/bus/%s/devices/%s/new_device", bus, entry->d_name);
+			if (access(filename, W_OK) == 0)
+				is_adapter = true;
+
+			snprintf(filename, PATH_MAX, "/sys/bus/%s/devices/%s/name", bus, entry->d_name);
 			file.open(filename, ios::in);
 			if (file) {
-				file >> devname;
+				getline(file, devname);
 				file.close();
 			}
 
-			sprintf(dev_name, _("I2C Device: %s"), devname);
+			snprintf(dev_name, 4096, _("I2C %s (%s): %s"), (is_adapter ? _("Adapter") : _("Device")), entry->d_name, devname.c_str());
 			dev->set_human_name(dev_name);
 		}
 
 		if (strcmp(bus, "pci") == 0) {
 			uint16_t vendor = 0, device = 0;
 
-			sprintf(filename, "/sys/bus/%s/devices/%s/vendor", bus, entry->d_name);
+			snprintf(filename, PATH_MAX, "/sys/bus/%s/devices/%s/vendor", bus, entry->d_name);
 
 			file.open(filename, ios::in);
 			if (file) {
@@ -221,7 +228,7 @@ static void do_bus(const char *bus)
 			}
 
 
-			sprintf(filename, "/sys/bus/%s/devices/%s/device", bus, entry->d_name);
+			snprintf(filename, PATH_MAX, "/sys/bus/%s/devices/%s/device", bus, entry->d_name);
 			file.open(filename, ios::in);
 			if (file) {
 				file >> hex >> device;
@@ -230,7 +237,7 @@ static void do_bus(const char *bus)
 
 			if (vendor && device) {
 				char devname[4096];
-				sprintf(devname, _("PCI Device: %s"),
+				snprintf(devname, 4096, _("PCI Device: %s"),
 					pci_id_to_name(vendor, device, filename, 4095));
 				dev->set_human_name(devname);
 			}
