@@ -34,6 +34,7 @@
 #include <stdio.h>
 #include <math.h>
 #include <stdlib.h>
+#include <limits.h>
 
 #include "lib.h"
 
@@ -236,10 +237,10 @@ string read_sysfs_string(const char *format, const char *param)
 	ifstream file;
 	char content[4096];
 	char *c;
-	char filename[8192];
+	char filename[PATH_MAX];
 
 
-	snprintf(filename, 8191, format, param);
+	snprintf(filename, PATH_MAX, format, param);
 
 	file.open(filename, ios::in);
 	if (!file)
@@ -474,10 +475,10 @@ int read_msr(int cpu, uint64_t offset, uint64_t *value)
 	int fd;
 	char msr_path[256];
 
-	sprintf(msr_path, "/dev/cpu/%d/msr", cpu);
+	snprintf(msr_path, 256, "/dev/cpu/%d/msr", cpu);
 
 	if (access(msr_path, R_OK) != 0){
-		sprintf(msr_path, "/dev/msr%d", cpu);
+		snprintf(msr_path, 256, "/dev/msr%d", cpu);
 
 		if (access(msr_path, R_OK) != 0){
 			fprintf(stderr,
@@ -506,10 +507,10 @@ int write_msr(int cpu, uint64_t offset, uint64_t value)
 	int fd;
 	char msr_path[256];
 
-	sprintf(msr_path, "/dev/cpu/%d/msr", cpu);
+	snprintf(msr_path, 256, "/dev/cpu/%d/msr", cpu);
 
 	if (access(msr_path, R_OK) != 0){
-		sprintf(msr_path, "/dev/msr%d", cpu);
+		snprintf(msr_path, 256, "/dev/msr%d", cpu);
 
 		if (access(msr_path, R_OK) != 0){
 			fprintf(stderr,
