@@ -34,6 +34,7 @@
 #include <unistd.h>
 #include <sys/types.h>
 #include <dirent.h>
+#include <limits.h>
 
 #include "../lib.h"
 #include "../devices/runtime_pm.h"
@@ -49,10 +50,10 @@ runtime_tunable::runtime_tunable(const char *path, const char *bus, const char *
 		sprintf(desc, _("%s device %s has no runtime power management"), bus, dev);
 
 	if (strcmp(bus, "pci") == 0) {
-		char filename[4096];
+		char filename[PATH_MAX];
 		uint16_t vendor = 0, device = 0;
 
-		sprintf(filename, "/sys/bus/%s/devices/%s/vendor", bus, dev);
+		snprintf(filename, PATH_MAX, "/sys/bus/%s/devices/%s/vendor", bus, dev);
 
 		file.open(filename, ios::in);
 		if (file) {
@@ -61,7 +62,7 @@ runtime_tunable::runtime_tunable(const char *path, const char *bus, const char *
 		}
 
 
-		sprintf(filename, "/sys/bus/%s/devices/%s/device", bus, dev);
+		snprintf(filename, PATH_MAX, "/sys/bus/%s/devices/%s/device", bus, dev);
 		file.open(filename, ios::in);
 		if (file) {
 			file >> hex >> device;
@@ -77,8 +78,8 @@ runtime_tunable::runtime_tunable(const char *path, const char *bus, const char *
 
 
 	}
-	sprintf(toggle_good, "echo 'auto' > '%s';", runtime_path);
-	sprintf(toggle_bad, "echo 'on' > '%s';", runtime_path);
+	snprintf(toggle_good, 4096, "echo 'auto' > '%s';", runtime_path);
+	snprintf(toggle_bad, 4096, "echo 'on' > '%s';", runtime_path);
 }
 
 int runtime_tunable::good_bad(void)
@@ -123,9 +124,9 @@ void add_runtime_tunables(const char *bus)
 {
 	struct dirent *entry;
 	DIR *dir;
-	char filename[4096];
+	char filename[PATH_MAX];
 
-	sprintf(filename, "/sys/bus/%s/devices/", bus);
+	snprintf(filename, PATH_MAX, "/sys/bus/%s/devices/", bus);
 	dir = opendir(filename);
 	if (!dir)
 		return;
@@ -139,13 +140,13 @@ void add_runtime_tunables(const char *bus)
 		if (entry->d_name[0] == '.')
 			continue;
 
-		sprintf(filename, "/sys/bus/%s/devices/%s/power/control", bus, entry->d_name);
+		snprintf(filename, PATH_MAX, "/sys/bus/%s/devices/%s/power/control", bus, entry->d_name);
 
 		if (access(filename, R_OK) != 0)
 			continue;
 
 
-		sprintf(filename, "/sys/bus/%s/devices/%s", bus, entry->d_name);
+		snprintf(filename, PATH_MAX, "/sys/bus/%s/devices/%s", bus, entry->d_name);
 
 		runtime = new class runtime_tunable(filename, bus, entry->d_name);
 
